@@ -10,16 +10,12 @@ no if $] > 5.017010, warnings => 'experimental::smartmatch';
 use English qw( -no_match_vars );
 local $OUTPUT_AUTOFLUSH = 1;
 
-our $VERSION = '0.26';
+our $VERSION = '0.28';
 
-BEGIN {
-	use Term::ReadLine;
-	$ENV{TERM} = 'dumb' if !exists $ENV{TERM};
-
-	eval { my $term = Term::ReadLine->new('none') };
-	if ($EVAL_ERROR) {
-		local $ENV{PERL_RL} = ' ornaments=0';
-	}
+use Term::ReadLine;
+if ( $OSNAME eq 'MSWin32' ) {
+	$ENV{TERM} = 'dumb';
+	local $ENV{PERL_RL} = ' ornaments=0';
 }
 
 use utf8;
@@ -696,7 +692,7 @@ Debug::Client - debugger client side code for Padre, The Perl IDE.
 
 =head1 VERSION
 
-This document describes Debug::Client version: 0.26
+This document describes Debug::Client version: 0.28
 
 =head1 SYNOPSIS
 
